Next we examine a simple system for reading input called a {glossary-link term="finite-state-automaton" reference-text="Formal languages"}finite state automaton{glossary-link end}, which --- as we'll find out later --- is closely related to {glossary-link term="regular-expression"}regular expressions{glossary-link end}.
Later we'll explore the idea of {glossary-link term="grammar"}grammars{glossary-link end}, another kind of formal language that can deal with more complicated forms of input.
